@@ -10,12 +10,16 @@ use File::Copy;
 use Getopt::Std;
 use Novel::Robot;
 use POSIX qw/ceil/;
+use FindBin;
+use Data::Dumper;
 
 $| = 1;
 binmode( STDIN,  ":encoding(console_in)" );
 binmode( STDOUT, ":encoding(console_out)" );
 binmode( STDERR, ":encoding(console_out)" );
 
+our $GET_NOVEL = "$FindBin::RealBin/get_novel.pl ";
+
 my %opt;
 getopt( 'sfwbutTGCSoh', \%opt );
 
@@ -52,7 +56,7 @@ sub main_ebook {
       $msg = decode( locale => $o{f} );
     }
   } elsif($o{u}) {
-    my $info = decode( locale => `get_novel.pl -u "$o{u}" -D 1` );
+    my $info = decode( locale => `$GET_NOVEL -u "$o{u}" -D 1` );
     chomp( $info );
     my ( $writer, $book, $url, $chap_num ) = split ',', $info;
     $writer = $o{w} if($o{w});
@@ -75,11 +79,11 @@ sub get_ebook {
   my ( $fh, $html_f ) = tempfile( "run_novel-html-XXXXXXXXXXXXXX", TMPDIR => 1, SUFFIX => ".html" );
   if ( $src and -f $src ) {
     my $s = decode( locale => $src );
-    system( encode( locale => qq[get_novel.pl -f "$s" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
+    system( encode( locale => qq[$GET_NOVEL -f "$s" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
   } elsif($src) {
-    system( encode( locale => qq[get_novel.pl -u "$src" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
+    system( encode( locale => qq[$GET_NOVEL -u "$src" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
   } else {
-    system( encode( locale => qq[get_novel.pl -s "$o{s}" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
+    system( encode( locale => qq[$GET_NOVEL -s "$o{s}" -w "$writer" -b "$book" -o $html_f $o{G}] ) );
   }
 
   my $min_id='';
@@ -104,7 +108,7 @@ sub get_ebook {
     : ( '', $ebook_f );
   print "conv to ebook $f_e\n";
   if ( $type ne 'html' ) {
-    system( encode( locale => qq[conv_novel.pl -f "$html_f" -t "$f_e" -w "$writer" -b "$book" $o{C}] ) );
+    system( encode( locale => qq[conv_novel.pl -f "$html_f" -T "$f_e" -w "$writer" -b "$book" $o{C}] ) );
     unlink( $html_f );
   } else {
     rename( $html_f, $f_e );
